@@ -1,6 +1,7 @@
+import os
+
 import click
-from PyWhat import identifier
-from PyWhat import printer
+from PyWhat import identifier, printer
 
 
 @click.command()
@@ -38,5 +39,7 @@ class What_Object:
         return self.id.identify(text)
 
 
+os.chdir(os.path.dirname(os.path.abspath(__file__)))
+
 if __name__ == "__main__":
     main()
